from django.conf import settings
from django_auth_ldap.config import _LDAPConfig

from inventory.models import RacksUser, RacksGroup


def map_user_attrs(attrs):
    model_attrs = {
        'username': attrs[settings.LDAP_USERNAME_ATTR][0],
    }

    for model_attr, ldap_attr in settings.AUTH_LDAP_USER_ATTR_MAP.items():
        if ldap_attr in attrs:
            model_attrs[model_attr] = attrs[ldap_attr][0]

    return model_attrs


def get_ldap_users(connection):
    user_search = settings.LDAP_USER_SEARCH

    result = user_search.execute(connection)

    return [
        (dn, map_user_attrs(attrs))
        for dn, attrs in result
    ]


def get_ldap_groups(connection):
    group_search = settings.AUTH_LDAP_GROUP_SEARCH

    result = group_search.execute(connection)

    return [attrs for dn, attrs in result]


def import_users():
    ldap = _LDAPConfig.get_ldap()

    connection = ldap.initialize(settings.AUTH_LDAP_SERVER_URI)

    users = {
        u.username: u for u in RacksUser.objects.all()
    }

    users_by_dn = {}

    for dn, model_attrs in get_ldap_users(connection):
        username = model_attrs['username']
        try:
            user = users.pop(username)
        except KeyError:
            user = RacksUser()
        user.deleted = False
        for name, value in model_attrs.items():
            setattr(user, name, value)
        user.save()
        users_by_dn[dn] = user

    # Delete users not present in LDAP catalog
    for user in users.values():
        user.prune()

    groups = {g.name: g for g in RacksGroup.objects.all()}

    for group_attrs in get_ldap_groups(connection):
        name = group_attrs['cn'][0]
        try:
            racks_group = groups.pop(name)
        except KeyError:
            racks_group = RacksGroup(name=name)

        racks_group.deleted = False
        racks_group.save()

        group_users = []

        for dn in group_attrs.get('member', []):
            try:
                user = users_by_dn[dn]
            except KeyError:
                continue

            group_users.append(user)

        racks_group.users = group_users

    for racks_group in groups.values():
        racks_group.prune()
