#!/usr/bin/env python

import json
import logging
import re

import requests
from django.conf import settings

from inventory.models import InventoryObject, InventoryObjectType


log = logging.getLogger(__name__)


def import_puppet_attributes():
    config = settings.PUPPET

    if config is None:
        log.warning('No puppet configuration, skipping import.')
        return

    re_ignore_keys = config.get('ignore_regex')

    http_headers = {
        'User-agent': config.get('user_agent', 'Racks Puppet Importer/0.2'),
    }

    for inventory_object in InventoryObject.objects.filter(name__isnull=False):
        resp = requests.get(
            '%s/puppet/node/%s?environment=production' % (
                config.get('puppet_url'), inventory_object.name),
            cert=(config.get('puppet_ssl_cert'), config.get('puppet_ssl_key')),
            verify=config.get('puppet_ssl_verify', False),
            headers=http_headers)

        attributes = {}

        try:
            facts = json.loads(resp.text)
        except ValueError:
            print resp.text
            continue

        object_type = None

        if 'data' in facts:
            if 'parameters' in facts['data']:
                parameters = facts['data']['parameters']

                if 'virtual' in parameters:
                    if parameters['virtual'] == 'physical':
                        object_type = 'HW Server'
                    elif parameters['virtual'] == 'kvm':
                        object_type = 'KVM Virtual Machine'

                for attribute in parameters.keys():
                    if not re.match(re_ignore_keys, attribute):
                        attributes[attribute] = parameters[
                            attribute]

        obj_type, created = InventoryObjectType.objects.get_or_create(name=object_type)

        if inventory_object.type != obj_type:
            inventory_object.type = obj_type
            inventory_object.save()

        inventory_object.update_attributes(attributes)
