#!/usr/bin/env python

import pyzabbix
from django.conf import settings

from inventory.models import InventoryObject, L2Address


def import_hosts():
    api = pyzabbix.ZabbixAPI(settings.ZABBIX_URL)
    api.login(settings.ZABBIX_USER, settings.ZABBIX_PASSWORD)

    groups = api.hostgroup.get(output='extend')
    hostlist = {}
    for group in groups:
        hosts = api.host.get(
            output='extend',
            groupids=group['groupid'],
            selectInventory=True)
        for host in hosts:
            fqdn = host['host']
            hostlist[fqdn] = host

            inventory_object, _ = InventoryObject.objects.get_or_create(name=host['host'])

            attributes = {
                'fqdn': host['host']
            }

            inventory = host.get('inventory') or {}

            if 'hardware' in inventory:
                attributes['hardware'] = inventory['hardware']

            if 'software_app_a' in inventory:
                attributes['version'] = inventory['software_app_a']

            macaddresses = [
                inventory[mac_address_property]
                for mac_address_property in ['macaddress_a', 'macaddress_b']
                if inventory.get(mac_address_property)
            ]

            inventory_object.l2addresses.clear()

            for raw_mac_address in macaddresses:
                mac_address = raw_mac_address.replace(':', '')
                assert L2Address.is_valid_mac_address(mac_address)

                try:
                    l2address = L2Address.objects.get(address=mac_address)
                except L2Address.DoesNotExist:
                    l2address = L2Address(address=mac_address)
                l2address.inventory_object = inventory_object
                l2address.save()

            if 'hostid' in host:
                attributes['zabbix_host_id'] = host['hostid']

            interfaces = api.hostinterface.get(
                output='extend',
                hostids=host['hostid'])

            for interface in interfaces:
                # IPMI interface
                if interface['type'] == '3':
                    if interface['dns'] != '':
                        attributes['ipmi_host'] = interface['dns']
                    else:
                        attributes['ipmi_host'] = interface['ip']

            inventory_object.update_attributes(attributes)
