from django import forms
from django.db import models
from south.modelsinspector import add_introspection_rules


class NullableCharFieldFormField(forms.CharField):
    def to_python(self, *args, **kwargs):
        value = super(NullableCharFieldFormField, self).to_python(*args, **kwargs)

        if value == '':
            value = None

        return value


class NullableCharField(models.CharField):
    def formfield(self, **kwargs):
        defaults = {
            'form_class': NullableCharFieldFormField
        }

        defaults.update(kwargs)
        return super(NullableCharField, self).formfield(**defaults)


add_introspection_rules([], [r"^inventory\.fields\.NullableCharField"])
