from django import template
from django.utils.html import mark_safe

from security.permissions import can_view

register = template.Library()


NO_ACCESS_MESSAGE = mark_safe(
    '<span class="text-danger">You do not have permission to view value of this field</span>'
)


@register.filter
def may_not_have_access(value):
    if not can_view(value):
        return NO_ACCESS_MESSAGE

    return value


@register.filter
def and_have_access(value):
    if not can_view(value):
        return False

    return value and True


@register.simple_tag
def no_access():
    return NO_ACCESS_MESSAGE
