from rest_framework import filters, viewsets

from inventory.models import (
    InventoryObject,
    InventoryObjectAttribute,
    InventoryObjectLabel,
    IPv4Network,
    RacksUser,
)

from inventory.serializers import UserSerializer
from inventory.serializers import InventoryObjectAttributeSerializer
from inventory.serializers import InventoryObjectLabelSerializer
from inventory.serializers import InventoryObjectSerializer
from inventory.serializers import IPv4NetworkSerializer


class UserViewSet(viewsets.ModelViewSet):
    queryset = RacksUser.objects.all()
    serializer_class = UserSerializer
    filter_backends = (filters.DjangoFilterBackend, filters.OrderingFilter)
    filter_fields = ('id', 'username', 'email', 'inventory_objects')
    ordering_fields = ('id',)
    ordering = ('username')


class InventoryObjectViewSet(viewsets.ModelViewSet):
    queryset = (InventoryObject.objects.all()
                .order_by('-created')
                .select_related('facter_location', 'facter_location__location'))
    serializer_class = InventoryObjectSerializer
    filter_backends = (filters.DjangoFilterBackend, filters.OrderingFilter)
    filter_fields = (
        'name',
        'responsible',
        'facter_location__fact',
        'type__name')
    ordering_fields = ('id',)


class IPv4NetworkViewSet(viewsets.ModelViewSet):
    queryset = IPv4Network.objects.all().order_by('-created')
    serializer_class = IPv4NetworkSerializer


class InventoryObjectAttributeViewSet(viewsets.ModelViewSet):
    queryset = InventoryObjectAttribute.objects.all().order_by('object', 'name')
    serializer_class = InventoryObjectAttributeSerializer
    filter_fields = ('object', 'name')


class InventoryObjectLabelViewSet(viewsets.ModelViewSet):
    queryset = InventoryObjectLabel.objects.all().order_by('name')
    serializer_class = InventoryObjectLabelSerializer
    filter_fields = ('inventory_objects',)
