import csv

from django.contrib.auth.decorators import login_required
from django.contrib.auth.models import User
from django.shortcuts import render
from django.shortcuts import HttpResponse

from inventory.models import (
    InventoryObject,
    InventoryObjectAttribute,
    InventoryObjectLabel,
)


@login_required
def labels(request):
    labels = InventoryObjectLabel.objects.all()

    return render(request, 'inventory/labels.html', {
        'labels': labels,
    })


@login_required
def search(request):
    query = request.GET.get('query')
    attributes = InventoryObjectAttribute.objects.filter(
        value__icontains=query)

    return render(request, 'inventory/search.html', {
        'attributes': attributes,
        'query': query,
    })


@login_required
def export_object_inventory(request):
    label = request.GET.get('label')
    responsible = request.GET.get('responsible')

    filters = {}
    if label is not None:
        filters['label'] = InventoryObjectLabel.objects.get(name=label)

    if responsible is not None:
        filters['responsible'] = User.objects.get(username=responsible)

    object_list = InventoryObject.objects.exclude(name=None).filter(**filters)

    columns = [
        'name',
        'location_name',
        'location_fact',
        'hardware',
        'macaddress_string',
        'type',
        'label_string',
        'jira_issue',
        'responsible_string',
    ]

    response = HttpResponse(
        content_type='text/csv',
        reason='Ok',
    )
    writer = csv.writer(response)
    writer.writerow(columns)
    for i in object_list:
        writer.writerow([getattr(i, c) for c in columns])

    return response
