from django import forms
from django.template.loader import render_to_string
from django.utils.datastructures import MultiValueDict, MergeDict
from django.utils.encoding import force_text


class FilteredSelectMultiple(forms.Select):
    allow_multiple_selected = True

    def render(self, name, value, attrs=None):
        # Normalize to strings.
        selected_choices = set(force_text(v) for v in value or [])

        choices = [
            (choice_value, text, value and force_text(choice_value) in selected_choices)
            for choice_value, text in self.choices
        ]

        return render_to_string('inventory/filtered-select-multiple.html', {
            'name': name,
            'choices': choices,
            'attrs': self.attrs,
        })

    def value_from_datadict(self, data, files, name):
        if isinstance(data, (MultiValueDict, MergeDict)):
            return data.getlist(name)
        return data.get(name, None)
