from django.core.urlresolvers import reverse


class Section(object):
    def __init__(self, label, subsections):
        self.label = label
        self.subsections = subsections

    def __iter__(self):
        return iter(self.subsections)

    @property
    def url(self):
        return self.subsections[0].url


class Subsection(object):
    def __init__(self, label, main_url_name, url_name_prefix=None):
        self.label = label
        self.main_url_name = main_url_name
        self.url_name_prefix = url_name_prefix

    @property
    def url(self):
        return reverse(self.main_url_name)


class Navigation(object):
    def __init__(self, sections, active_section, active_subsection):
        self.sections = sections
        self.active_section = active_section
        self.active_subsection = active_subsection


SECTIONS = [
    Section('Inventory', [
        Subsection('Objects', 'inventory.objects.list', 'inventory.objects.'),
        Subsection('Labs', 'inventory.labs.list', 'inventory.labs.'),
        Subsection('Labels', 'inventory.views.misc.labels'),
        Subsection('Locations', 'inventory.locations.list', 'inventory.locations.'),
        Subsection('IPv4 Networks', 'inventory.ipv4networks.list', 'inventory.ipv4networks.'),
        Subsection('VLANs', 'inventory.vlans.list', 'inventory.vlans.')
    ]),
    Section('Reports', [
        Subsection('Basic reports', 'reports.views.basic'),
    ]),
    Section('Account', [
        Subsection('Applications', 'security.applications.list',
                   'security.applications.'),
        Subsection('Profile', 'security.views.profile'),
        Subsection('Assigned', 'account.assigned'),
        Subsection('Responsible', 'account.responsible'),
    ]),
]


class NavigationMiddleware:
    def get_active(self, request):
        for section in SECTIONS:
            for subsection in section.subsections:
                url_name = request.resolver_match.url_name
                if url_name == subsection.main_url_name or \
                   subsection.url_name_prefix and url_name.startswith(subsection.url_name_prefix):
                    return section, subsection

        return None, None

    def process_view(self, request, view_func, view_args, view_kwargs):
        section, subsection = self.get_active(request)

        request.navigation = Navigation(SECTIONS, section, subsection)
