$('document').ready(function() {
  // Copied verbatim from https://docs.djangoproject.com/en/1.9/ref/csrf/
  function getCookie(name) {
    var cookieValue = null;
    if (document.cookie && document.cookie !== '') {
      var cookies = document.cookie.split(';');
      for (var i = 0; i < cookies.length; i++) {
        var cookie = jQuery.trim(cookies[i]);
        // Does this cookie string begin with the name we want?
        if (cookie.substring(0, name.length + 1) == (name + '=')) {
          cookieValue = decodeURIComponent(cookie.substring(name.length + 1));
          break;
        }
      }
    }
    return cookieValue;
  }

  var csrftoken = getCookie('csrftoken');

  function csrfSafeMethod(method) {
    // these HTTP methods do not require CSRF protection
    return (/^(GET|HEAD|OPTIONS|TRACE)$/.test(method));
  }
  $.ajaxSetup({
    beforeSend: function(xhr, settings) {
      if (!csrfSafeMethod(settings.type) && !this.crossDomain) {
        xhr.setRequestHeader('X-CSRFToken', csrftoken);
      }
    }
  });
  // End of verbatim copies

  var searchSuggestions = new Bloodhound({
    datumTokenizer: Bloodhound.tokenizers.obj.whitespace('value'),
    queryTokenizer: Bloodhound.tokenizers.whitespace,
    remote: {
      url: '/api/v1/search/suggest.json?query=%QUERY&limit=5',
      wildcard: '%QUERY'
    }
  });

  $('#addMeAsAResponsible').click(function() {
    var objectid = $('#inventoryobjectid').val();
    var payload;
    $.getJSON('/api/v2/objects/' + objectid + '/', function(data) {
      var persons = data.responsible;
      persons.push($('#currentUserName').val());
      payload = {
        responsible: persons
      };
      console.log(payload);
      $.ajax({
        type: 'PATCH',
        url: '/api/v2/objects/' + objectid + '/',
        data: JSON.stringify(payload),
        dataType: 'json',
        contentType: 'application/json; charset=UTF-8',
        jsonp: false,
        success: function(data) {
          $(location).attr('href', '/' + objectid);
        }
      });
    });
  });

  $('#labelsForm')
        .find('[name="labels"]')
            .change(function(e) {
              objectid = $('#objectid').val();
              var payload = {
                id: objectid,
                labels: $(this).tagsinput('items')
              };
              $.ajax({
                type: 'PATCH',
                url: '/api/v2/objects/' + objectid + '/',
                data: JSON.stringify(payload),
                dataType: 'json',
                contentType: 'application/json; charset=UTF-8',
                jsonp: false
              });
            })
            .end();

  $('#removeMeAsAResponsible').click(function() {
    var objectid = $('#inventoryobjectid').val();
    var payload;
    $.getJSON('/api/v2/objects/' + objectid + '/', function(data) {
      var persons = data.responsible;
      persons = $.grep(persons, function(n, id) {
        return (n != $('#currentUserName').val());
      });
      payload = {
        responsible: persons
      };
      console.log(payload);
      $.ajax({
        type: 'PATCH',
        url: '/api/v2/objects/' + objectid + '/',
        data: JSON.stringify(payload),
        dataType: 'json',
        contentType: 'application/json; charset=UTF-8',
        jsonp: false,
        success: function(data) {
          $(location).attr('href', '/' + objectid);
        }
      });
    });
  });

  $('#searchqueryinput').typeahead(null, {
    name: 'searchSuggestions',
    source: searchSuggestions
  });

  $('[data-suggestions]').each(function() {
    var localSuggestions = new Bloodhound({
      datumTokenizer: Bloodhound.tokenizers.whitespace,
      queryTokenizer: Bloodhound.tokenizers.whitespace,
      local: JSON.parse($(this).attr('data-suggestions'))
    });

    $(this).typeahead(null, {name: 'local', source: localSuggestions});
  });

  function initConfirmDeleteRow() {
    var dialog = $('#confirm-delete-dialog');

    dialog.find('button[name=cancel]').click(function() {
      dialog.modal('hide');
    });

    $('.confirm-delete-row').click(function(e) {
      e.preventDefault();

      var rowName = $(this).parents('tr').find('.row-name').html();
      $('#confirm-delete-dialog-row-name').html(rowName);
      dialog.find('form').attr('action', this.href);
      dialog.modal();
    });
  }

  initConfirmDeleteRow();

  $('.filtered-select-multiple').each(function() {
    function HalfControl(elem) {
      var _this = this;

      this.select = elem.find('.select');
      this.options = this.select.find('.option');
      this.button = elem.find('.transfer-button');

      this.onChange = function() {
        var selected = this.options.filter('.selected');
        this.button.attr('disabled', !selected.length);
      };

      this.lastClickedOption = null;

      this.options.click(function(e) {
        e.stopPropagation();
        e.preventDefault();

        if (!e.ctrlKey) {
          _this.options.removeClass('selected');
        }

        if (e.shiftKey) {
          if (_this.lastClickedOption) {
            var lastClickedIndex = _this.options.index(_this.lastClickedOption);
            var thisClickedIndex = _this.options.index(this);

            var fromIndex = Math.min(lastClickedIndex, thisClickedIndex);
            var toIndex = Math.max(lastClickedIndex, thisClickedIndex) + 1;

            var selection = _this.options.slice(fromIndex, toIndex)
                                         .filter('.available:not(.hidden)');

            selection.addClass('selected');
          }
        } else {
          _this.lastClickedOption = this;
          $(this).addClass('selected');
        }

        _this.onChange();
      });

      var filterInput = elem.find('.filter-input');
      var prevFilterValue;

      filterInput.on('keyup change', delay(function(e) {
        var filterValue = filterInput.val();

        if (filterValue !== prevFilterValue) {
          var re = new RegExp(filterValue, 'i');

          _this.options.each(function() {
            var option = $(this);
            var matching = option.attr('data-text').search(re) !== -1;

            if (!matching) {
              option.addClass('hidden').removeClass('selected');
            } else {
              option.removeClass('hidden');
            }

            prevFilterValue = filterValue;
          });

          _this.onChange();
        }
      }, 100));
    }

    var available = new HalfControl($('.available-control', this));
    var selected = new HalfControl($('.selected-control', this));
    var hiddenSelect = $('select[hidden]', this);
    var valToRow = {};

    available.options.each(function(i) {
      var value = $(this).attr('data-value');
      valToRow[value] = i;
    });

    function transfer(from, to) {
      var selectedOptions = from.options.filter('.selected');

      // Clear selection in target select
      to.options.removeClass('selected');

      selectedOptions.each(function() {
        var value = $(this).attr('data-value');
        var row = valToRow[value];
        from.options.eq(row).removeClass('selected available');
        to.options.eq(row).addClass('selected available');

        return value;
      });

      var selectedValues = selected.options.filter('.available').map(function() {
        return $(this).attr('data-value');
      });

      hiddenSelect.val(selectedValues);

      from.onChange();
      to.onChange();

      to.select.focus();
    }

    function delay(callback, timeout) {
      var timer;

      return function() {
        var _this = this;
        var _arguments = arguments;

        if (timer !== undefined) {
          window.clearTimeout(timer);
        }

        timer = window.setTimeout(function() {
          callback.apply(_this, _arguments);
        }, timeout);
      };
    }

    available.button.click(function() {
      transfer(available, selected);
    });
    selected.button.click(function() {
      transfer(selected, available);
    });
  });
});
