from django.conf.urls import include, patterns, url
from rest_framework import routers

from inventory.views import api_v2

router = routers.DefaultRouter()
router.register(r'users', api_v2.UserViewSet)
router.register(r'objects', api_v2.InventoryObjectViewSet)
router.register(r'ipv4networks', api_v2.IPv4NetworkViewSet)
router.register(r'attributes', api_v2.InventoryObjectAttributeViewSet)
router.register(r'labels', api_v2.InventoryObjectLabelViewSet)

urlpatterns = patterns(
    '',
    # API v2 views
    (r'^api\/v2\/', include(router.urls)),

    # Old urls
    url(r'^account\/applications/(?P<applicationid>[0-9]+)\.html', 'security.views.application',
        name='security.applications.view'),
    url(r'^account\/applications\.html$', 'security.views.applications',
        name='security.applications.list'),
    (r'^account\/profile\.html$', 'security.views.profile'),
    (r'^export\/object\/inventory\.csv',
        'inventory.views.misc.export_object_inventory'),
    (r'^labels\.html$', 'inventory.views.misc.labels'),
    (r'^reports\/basic\.html$', 'reports.views.basic'),
    url(r'^search\.html$', 'inventory.views.misc.search', name='inventory.objects.search'),
    (r'^account\/login\.html$', 'security.views.login_view'),
    (r'^account\/logout\.html$', 'security.views.logout_view'),

    url(r'^launchpad/authorize$', 'launchpad.views.authorize', name='launchpad.authorize'),
    url(r'^launchpad/fetchbugs$', 'launchpad.views.fetch_bugs_json'),

    url(r'^account/assigned', 'account.views.assigned', name='account.assigned'),
    url(r'^account/responsible$', 'account.views.responsible', name='account.responsible'),

    # Objects
    url(r'^', include('inventory.views.objects')),
    url(r'^labs/', include('inventory.views.labs')),
    url(r'^vlans/', include('inventory.views.vlans')),
    url(r'^locations/', include('inventory.views.locations')),
    url(r'^ipv4networks/', include('inventory.views.ipv4networks')),
)
