import functools
import json

from django.http import HttpResponse

from security.authentication import validate_token


def token_auth(view_func):
    @functools.wraps(view_func)
    def wrapper(request, *args, **kwargs):
        if not validate_token(request):
            return HttpResponse(
                content=json.dumps({
                    'status': 'error',
                    'reason': 'Authentication data is absent or invalid',
                }),
                content_type='application/json',
                status=403,
                reason='Forbidden'
            )

        return view_func(request, *args, **kwargs)

    return wrapper
