from django.contrib.auth.models import User
from django.db import models
from django.utils.translation import ugettext_lazy as _


class CreateTimeBaseObject(models.Model):
    created = models.DateTimeField(auto_now_add=True)
    modified = models.DateTimeField(auto_now=True)
    access = models.DateTimeField(blank=True, null=True, default=None)
    active = models.BooleanField(default=True)

    class Meta:
        abstract = True

    @property
    def pretty_access_time(self):
        if self.access is None:
            return _('Never')
        else:
            return self.access


class Application(CreateTimeBaseObject):
    name = models.CharField(max_length=128)
    auth_token = models.CharField(max_length=128, unique=True)
    user = models.ForeignKey(User, related_name='applications')

    class Meta:
        unique_together = ('name', 'user')

    def get_absolute_url(self):
        return '/account/applications/%s.html' % self.pk
