from rest_framework.permissions import BasePermission, SAFE_METHODS

from security.permissions import get_permissions


class Permissions(BasePermission):
    def has_permission(self, request, view):
        if request.method in SAFE_METHODS:
            return True

        model = None

        if getattr(view, 'model', None):
            model = view.model
        elif getattr(view, 'queryset', None):
            model = view.queryset.model

        permissions = get_permissions(request, model)

        # Create and delete should be decided here
        if request.method == 'POST':
            return permissions.create
        elif request.method == 'DELETE':
            return permissions.delete
        elif request.method == 'PATCH':
            # Update should be managed at serializer level
            return True

        return False
